##  EA-Centric Dashboard and Reporting
For each phase, SAP LeanIX has prepared templates with KPIs and reports as an inspiration for the EA-centric reporting. In the Discover phase, we suggest including the following metrics suggested by SAP LeanIX that can be set up with SAP LeanIX KPIs and presented in an SAP LeanIX Dashboard.
![Phase 1 Dashboard for overview and communication](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27494fb97a441014947dcaf0d226f23c_LowRes.gif)
Phase 1 Dashboard for overview and communication
  * Application Data Quality per Business Capability and Region (measured by % of Fact Sheet Completion): An Application Matrix Report providing a high-level overview of all Applications, clustered by Business Capabilities and User Groups involved in the transformation with a view of their completion. The color-coding shows the completion status of your Application Fact Sheet data.
![Matrix Report with Fact Sheet Completion view](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274830de7a44101490c8ba434957e18b_LowRes.png)
Matrix Report with Fact Sheet Completion view
  * Status quo of Scoping (measured by Business Capabilities reviewed): A pie chart showing the status of the Business Capability assessment by business owners, which is relevant for the scoping of your ERP transformation.
![Status of scoping](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274f6daa7a441014b77d9f0c5cb66db3_LowRes.png)
Status of scoping
  * Deep-dive Capability Assessment (number of approved Business Capabilities and break-down by assessment categories): Overview of KPIs to track how many Business Capabilities have been approved by assigned business owners and for how many Business Capabilities relevant dimensions (TIME, PACE Layer, Current Maturity, Target Maturity) have been assessed.
![Status of Business Capability Approval](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274f54c47a4410149afebf16e1110490_LowRes.png)
Status of Business Capability Approval
  * Applications, Organizations, and Interfaces in scope of the ERP Transformation: Overview of KPIs showing how large the scope of the ERP transformation is, based on the selected Business Capabilities. Helps answer questions such as “How many applications will we now need to move?”, “How many departments will be affected by this?”. These insights arm the EA with clear, tangible data points, with clickable links to inventory filters for further investigation.
![Overview of Applications, Organizations, and Interfaces in scope of the transformation](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2746868f7a4410149c93f56d95053964_LowRes.png)
Overview of Applications, Organizations, and Interfaces in scope of the transformation
  * Deep-dive Application Data Quality: Overview of KPIs showing approval and data completion status of your Applications in scope. Approval as the final, top-level metric to confirm that all the underlying dimensions are filled & correct on the Fact Sheet (Quality Seal available, Fact Sheet overall completed, Functional Fit assessment completed).
![Overview of Application Data completion and quality](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274d4eea7a44101490cdf5223eb35149_LowRes.png)
Overview of Application Data completion and quality
  * Deep-dive: Organization Data Quality: Organization Fact Sheets for Applications in scope with approved Quality Seal.
![Overview of Organization Fact Sheet data quality](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274a2bb97a441014aba2b858a4da0faa_LowRes.png)
Overview of Organization Fact Sheet data quality
  * Deep-dive: Objective Data Quality: Objective Fact Sheets for Applications in scope with approved Quality Seal
  * Deep-dive: Interfaces Data Quality: Interface Fact Sheets for Applications in scope with approved Quality Seal
